@@ -154,19 +154,22 @@ class MultiAuthPolicyTests(unittest.TestCase):
         policies = [TestAuthnPolicy2(), TestAuthnPolicy3()]
         policy = MultiAuthenticationPolicy(policies)
 
-        selected_policy = []
-
-        def track_policy(event):
-            selected_policy.append(event.policy)
-
         with testConfig() as config:
-            config.add_subscriber(track_policy, MultiAuthPolicySelected)
             request = DummyRequest()
 
+            selected_policy = []
+
+            def track_policy(event):
+                selected_policy.append((event.policy, event.request))
+
+            config.add_subscriber(track_policy, MultiAuthPolicySelected)
+
+
             self.assertEquals(policy.authenticated_userid(request), "test2")
 
-        self.assertEquals(selected_policy[0], policies[0])
-        self.assertEquals(len(selected_policy), 1)
+            self.assertEquals(selected_policy[0][0], policies[0])
+            self.assertEquals(selected_policy[0][1], request)
+            self.assertEquals(len(selected_policy), 1)
 
     def test_stacking_of_unauthenticated_userid(self):
         policies = [TestAuthnPolicy2(), TestAuthnPolicy3()]
